==> haskell-brick-0.46-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.46
id: brick-0.46-1IZkU25a2lQKg8TuHO0ZDe
key: brick-0.46-1IZkU25a2lQKg8TuHO0ZDe
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: 43128b2fb1bc694be1fcde66c15e7b84
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/brick-0.46
library-dirs: /usr/lib/ghc-8.6.3/site-local/brick-0.46
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/brick-0.46
hs-libraries: HSbrick-0.46-1IZkU25a2lQKg8TuHO0ZDe
depends:
    base-4.12.0.0 config-ini-0.2.4.0-AWKb2qaerMfBKRVHTvea4Z
    containers-0.6.0.1 contravariant-1.5-4tjvhiNPMk29NhGPKE1GIF
    data-clist-0.1.2.2-GzocsQSAGiLI5xv2Z1hpjW deepseq-1.4.4.0
    directory-1.3.3.0 dlist-0.8.0.5-HU8Aimky3DbFEV0DkwGifS
    filepath-1.4.2.1 microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    microlens-mtl-0.1.11.1-ArOkR9uJEwUKhorO3NKX6K
    microlens-th-0.4.2.3-CUJusVERdhn2qUrB8UezE5 stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    text-zipper-0.10.1-CMi4VMamr6K9xvNtfzwJ6m transformers-0.5.5.0
    unix-2.7.2.2 vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
    vty-5.25.1-54YYfSBdOFB50212qK8e01
    word-wrap-0.4.1-F0L8HkbCM7NBQieEGBBc6b
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brick-0.46-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.46
id: brick-0.46-AH9qRX5WmCJEaEjskDqxne
key: brick-0.46-AH9qRX5WmCJEaEjskDqxne
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: 30b3e078ab2641d9f669cb392e9e32f7
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/brick-0.46
library-dirs: /usr/lib/ghc-8.6.3/site-local/brick-0.46
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/brick-0.46
hs-libraries: HSbrick-0.46-AH9qRX5WmCJEaEjskDqxne
depends:
    base-4.12.0.0 config-ini-0.2.4.0-7keGEu9Vt2IGp95h1vz0OH
    containers-0.6.0.1 contravariant-1.5-4tjvhiNPMk29NhGPKE1GIF
    data-clist-0.1.2.2-GzocsQSAGiLI5xv2Z1hpjW deepseq-1.4.4.0
    directory-1.3.3.0 dlist-0.8.0.5-HU8Aimky3DbFEV0DkwGifS
    filepath-1.4.2.1 microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    microlens-mtl-0.1.11.1-ArOkR9uJEwUKhorO3NKX6K
    microlens-th-0.4.2.3-Fml6sEERVfNEF1OzT61N9N stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    text-zipper-0.10.1-CMi4VMamr6K9xvNtfzwJ6m transformers-0.5.5.0
    unix-2.7.2.2 vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
    vty-5.25.1-AUjx7v55hQf8vFmNzQXe1w
    word-wrap-0.4.1-F0L8HkbCM7NBQieEGBBc6b
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
